=====================================
Detection of non-stationary processes
=====================================

.. automodule:: elephant.change_point_detection


References
----------

.. bibliography::
    :keyprefix: cpd-
